@@ -239,7 +239,7 @@ function(cross, pheno, method=c("em","mr"),
     }
 
     w <- names(map)
-    o <- grep("^loc\-*[0-9]+",w)
+    o <- grep("^loc-*[0-9]+",w)
     if(length(o) > 0) # inter-marker locations cited as "c*.loc*"
       w[o] <- paste("c",names(cross$geno)[i],".",w[o],sep="")
     rownames(z) <- w
