@@ -4,7 +4,7 @@
  *
  * copyright (c) 2001-6, Karl W Broman, Johns Hopkins University
  *
- * last modified Feb, 2006
+ * last modified Oct, 2006
  * first written Nov, 2001
  *
  * Licensed under the GNU General Public License version 2 (June, 1991)
@@ -109,7 +109,7 @@ void R_scantwo_2chr_em(int *n_ind, int *n_pos1, int *n_pos2,
 		       double *genoprob2, double *addcov, int *n_addcov, 
 		       double *intcov, int *n_intcov, 
 		       double *pheno, double *weights,
-		       double *result_full, double *result_int,
+		       double *result_full, double *result_add,
 		       int *maxit, double *tol, int *verbose);
 
 /**********************************************************************
@@ -152,8 +152,8 @@ void R_scantwo_2chr_em(int *n_ind, int *n_pos1, int *n_pos2,
  *              containing the joint LODs
  *              Note: indexed as Result[pos2][pos1]
  *
- * Result_int   Result matrix of size [n_pos2 x n_pos1] 
- *              containing the LODs testing interactions
+ * Result_add   Result matrix of size [n_pos2 x n_pos1] 
+ *              containing the LODs for add've models
  *              also indexed as Result[pos2][pos1]
  *
  * maxit        Maximum number of iterations for EM
@@ -172,7 +172,7 @@ void scantwo_2chr_em(int n_ind, int n_pos1, int n_pos2, int n_gen1,
 		     int n_gen2, double ***Genoprob1, double ***Genoprob2,
 		     double **Addcov, int n_addcov, double **Intcov, 
 		     int n_intcov, double *pheno, double *weights,
-		     double **Result_full, double **Result_int, 
+		     double **Result_full, double **Result_add, 
 		     int maxit, double tol, int verbose);
 
 /**********************************************************************
